/**
 * @file lcd_elements.hpp
 * @author Siwat Sirichai (siwat@siwatinc.com)
 * @brief Definitions of the LCD Elements (Pages, Elements, Pictures, etc.)
 * @version 0.1
 * @date 2024-03-19
 * 
 * @copyright Copyright (c) Siwat System 2024
 * 
 */
/*****************************************
 *               Page IDs                *
 * ***************************************/
#define LCD_PAGE_ID_BOOT 0
#define LCD_PAGE_ID_DASHBOARD 1

/*****************************************
 *    Dashboard Element & Picture IDs    *
 * ***************************************/
// Lights
#define LCD_DASHBOARD_ELEMENT_LIGHT_ALL 0
#define LCD_DASHBOARD_ELEMENT_NAME_LIGHT_ALL "light_all"
#define LCD_DASHBOARD_PIC_LIGHT_ALL_ON 0
#define LCD_DASHBOARD_PIC_LIGHT_ALL_ON_PRESSED 1
#define LCD_DASHBOARD_PIC_LIGHT_ALL_OFF 1
#define LCD_DASHBOARD_PIC_LIGHT_ALL_OFF_PRESSED 0

#define LCD_DASHBOARD_ELEMENT_LIGHT_1 0
#define LCD_DASHBOARD_ELEMENT_NAME_LIGHT_1 "light_1"
#define LCD_DASHBOARD_PIC_LIGHT_1_ON 2
#define LCD_DASHBOARD_PIC_LIGHT_1_ON_PRESSED 3
#define LCD_DASHBOARD_PIC_LIGHT_1_OFF 3
#define LCD_DASHBOARD_PIC_LIGHT_1_OFF_PRESSED 2

#define LCD_DASHBOARD_ELEMENT_LIGHT_2 1
#define LCD_DASHBOARD_ELEMENT_NAME_LIGHT_2 "light_2"
#define LCD_DASHBOARD_PIC_LIGHT_2_ON 4
#define LCD_DASHBOARD_PIC_LIGHT_2_ON_PRESSED 5
#define LCD_DASHBOARD_PIC_LIGHT_2_OFF 5
#define LCD_DASHBOARD_PIC_LIGHT_2_OFF_PRESSED 4

#define LCD_DASHBOARD_ELEMENT_LIGHT_3 2
#define LCD_DASHBOARD_ELEMENT_NAME_LIGHT_3 "light_3"
#define LCD_DASHBOARD_PIC_LIGHT_3_ON 6
#define LCD_DASHBOARD_PIC_LIGHT_3_ON_PRESSED 7
#define LCD_DASHBOARD_PIC_LIGHT_3_OFF 7
#define LCD_DASHBOARD_PIC_LIGHT_3_OFF_PRESSED 6

#define LCD_DASHBOARD_ELEMENT_LIGHT_4 3
#define LCD_DASHBOARD_ELEMENT_NAME_LIGHT_4 "light_4"
#define LCD_DASHBOARD_PIC_LIGHT_4_ON 8
#define LCD_DASHBOARD_PIC_LIGHT_4_ON_PRESSED 9
#define LCD_DASHBOARD_PIC_LIGHT_4_OFF 9
#define LCD_DASHBOARD_PIC_LIGHT_4_OFF_PRESSED 8

// Fans
#define LCD_DASHBOARD_ELEMENT_FAN_ALL 4
#define LCD_DASHBOARD_ELEMENT_NAME_FAN_ALL "fan_all"
#define LCD_DASHBOARD_PIC_FAN_ALL_ON 10
#define LCD_DASHBOARD_PIC_FAN_ALL_ON_PRESSED 11
#define LCD_DASHBOARD_PIC_FAN_ALL_OFF 11
#define LCD_DASHBOARD_PIC_FAN_ALL_OFF_PRESSED 10

#define LCD_DASHBOARD_ELEMENT_FAN_1 4
#define LCD_DASHBOARD_ELEMENT_NAME_FAN_1 "fan_1"
#define LCD_DASHBOARD_PIC_FAN_1_ON 12
#define LCD_DASHBOARD_PIC_FAN_1_ON_PRESSED 13
#define LCD_DASHBOARD_PIC_FAN_1_OFF 13
#define LCD_DASHBOARD_PIC_FAN_1_OFF_PRESSED 12

#define LCD_DASHBOARD_ELEMENT_FAN_2 5
#define LCD_DASHBOARD_ELEMENT_NAME_FAN_2 "fan_2"
#define LCD_DASHBOARD_PIC_FAN_2_ON 14
#define LCD_DASHBOARD_PIC_FAN_2_ON_PRESSED 15
#define LCD_DASHBOARD_PIC_FAN_2_OFF 15
#define LCD_DASHBOARD_PIC_FAN_2_OFF_PRESSED 14

#define LCD_DASHBOARD_ELEMENT_FAN_3 6
#define LCD_DASHBOARD_ELEMENT_NAME_FAN_3 "fan_3"
#define LCD_DASHBOARD_PIC_FAN_3_ON 16
#define LCD_DASHBOARD_PIC_FAN_3_ON_PRESSED 17
#define LCD_DASHBOARD_PIC_FAN_3_OFF 17
#define LCD_DASHBOARD_PIC_FAN_3_OFF_PRESSED 16

// Air Purifier
#define LCD_DASHBOARD_ELEMENT_AIR_PURIFIER 7
#define LCD_DASHBOARD_ELEMENT_NAME_AIR_PURIFIER "purifier"
#define LCD_DASHBOARD_PIC_AIR_PURIFIER_ON 18
#define LCD_DASHBOARD_PIC_AIR_PURIFIER_ON_PRESSED 19
#define LCD_DASHBOARD_PIC_AIR_PURIFIER_OFF 19
#define LCD_DASHBOARD_PIC_AIR_PURIFIER_OFF_PRESSED 18

// Mosquito Zapper
#define LCD_DASHBOARD_ELEMENT_MOSQUITO_ZAPPER 8
#define LCD_DASHBOARD_ELEMENT_NAME_MOSQUITO_ZAPPER "zapper"
#define LCD_DASHBOARD_PIC_MOSQUITO_ZAPPER_ON 20
#define LCD_DASHBOARD_PIC_MOSQUITO_ZAPPER_ON_PRESSED 21
#define LCD_DASHBOARD_PIC_MOSQUITO_ZAPPER_OFF 21
#define LCD_DASHBOARD_PIC_MOSQUITO_ZAPPER_OFF_PRESSED 20

// AQI
#define LCD_DASHBOARD_ELEMENT_AQI_TEXT 9
#define LCD_DASHBOARD_ELEMENT_NAME_AQI_TEXT "aqi_txt"
#define LCD_DASHBOARD_ELEMENT_AQI_PICTURE 10
#define LCD_DASHBOARD_ELEMENT_NAME_AQI_PICTURE "aqi_pic"
#define LCD_DASHBOARD_PIC_AQI_GOOD 22
#define LCD_DASHBOARD_PIC_AQI_MODERATE 23
#define LCD_DASHBOARD_PIC_AQI_UNHEALTHY_FOR_SENSITIVE_GROUPS 24
#define LCD_DASHBOARD_PIC_AQI_UNHEALTHY 25
#define LCD_DASHBOARD_PIC_AQI_VERY_UNHEALTHY 26
#define LCD_DASHBOARD_PIC_AQI_HAZARDOUS 27

// Socket Power
#define LCD_DASHBOARD_ELEMENT_SOCKET_POWER 11
#define LCD_DASHBOARD_ELEMENT_NAME_SOCKET_POWER "socket"
#define LCD_DASHBOARD_PIC_SOCKET_POWER_ON 28
#define LCD_DASHBOARD_PIC_SOCKET_POWER_OFF 29

// Air Conditioner
#define LCD_DASHBOARD_ELEMENT_AC_STATE 12
#define LCD_DASHBOARD_ELEMENT_NAME_AC_STATE "ac_state"
#define LCD_DASHBOARD_PIC_AC_STATE_OFF 30
#define LCD_DASHBOARD_PIC_AC_STATE_OFF_PRESSED 31
#define LCD_DASHBOARD_PIC_AC_STATE_OFF_LOCKED 31
#define LCD_DASHBOARD_PIC_AC_STATE_ON 32
#define LCD_DASHBOARD_PIC_AC_STATE_ON_PRESSED 33
#define LCD_DASHBOARD_PIC_AC_STATE_ON_LOCKED 33

#define LCD_DASHBOARD_ELEMENT_AC_MODE_FAN 13
#define LCD_DASHBOARD_ELEMENT_NAME_AC_MODE_FAN "ac_mode_fan"
#define LCD_DASHBOARD_PIC_AC_MODE_FAN_ACTIVE 34
#define LCD_DASHBOARD_PIC_AC_MODE_FAN_ACTIVE_PRESS 35
#define LCD_DASHBOARD_PIC_AC_MODE_FAN_INACTIVE 35
#define LCD_DASHBOARD_PIC_AC_MODE_FAN_INACTIVE_PRESS 34

#define LCD_DASHBOARD_ELEMENT_AC_MODE_COOL 14
#define LCD_DASHBOARD_ELEMENT_NAME_AC_MODE_COOL "ac_mode_cool"
#define LCD_DASHBOARD_PIC_AC_MODE_COOL_ACTIVE 36
#define LCD_DASHBOARD_PIC_AC_MODE_COOL_ACTIVE_PRESS 37
#define LCD_DASHBOARD_PIC_AC_MODE_COOL_INACTIVE 37
#define LCD_DASHBOARD_PIC_AC_MODE_COOL_INACTIVE_PRESS 36

#define LCD_DASHBOARD_ELEMENT_AC_FAN_SPEED_AUTO 15
#define LCD_DASHBOARD_ELEMENT_NAME_AC_FAN_SPEED_AUTO "ac_fan_auto"
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_AUTO_ACTIVE 38
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_AUTO_ACTIVE_PRESS 39
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_AUTO_INACTIVE 39
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_AUTO_INACTIVE_PRESS 38

#define LCD_DASHBOARD_ELEMENT_AC_FAN_SPEED_HIGH 16
#define LCD_DASHBOARD_ELEMENT_NAME_AC_FAN_SPEED_HIGH "ac_fan_high"
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_HIGH_ACTIVE 40
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_HIGH_ACTIVE_PRESS 41
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_HIGH_INACTIVE 41
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_HIGH_INACTIVE_PRESS 40

#define LCD_DASHBOARD_ELEMENT_AC_FAN_SPEED_MEDIUM 17
#define LCD_DASHBOARD_ELEMENT_NAME_AC_FAN_SPEED_MEDIUM "ac_fan_medium"
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_MEDIUM_ACTIVE 42
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_MEDIUM_ACTIVE_PRESS 43
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_MEDIUM_INACTIVE 43
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_MEDIUM_INACTIVE_PRESS 42

#define LCD_DASHBOARD_ELEMENT_AC_FAN_SPEED_LOW 18
#define LCD_DASHBOARD_ELEMENT_NAME_AC_FAN_SPEED_LOW "ac_fan_low"
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_LOW_ACTIVE 44
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_LOW_ACTIVE_PRESS 45
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_LOW_INACTIVE 45
#define LCD_DASHBOARD_PIC_AC_FAN_SPEED_LOW_INACTIVE_PRESS 44

#define LCD_DASHBOARD_ELEMENT_ROOM_TEMPERATURE 19
#define LCD_DASHBOARD_ELEMENT_NAME_ROOM_TEMPERATURE "room_temp"

// All System Button
#define LCD_DASHBOARD_ELEMENT_ALL_SYSTEM_TOGGLE 20
#define LCD_DASHBOARD_ELEMENT_NAME_ALL_SYSTEM_TOGGLE "all_toggle"
#define LCD_DASHBOARD_PIC_ALL_SYSTEM_TOGGLE_ON 46
#define LCD_DASHBOARD_PIC_ALL_SYSTEM_TOGGLE_ON_PRESSED 47
#define LCD_DASHBOARD_PIC_ALL_SYSTEM_TOGGLE_OFF 47
#define LCD_DASHBOARD_PIC_ALL_SYSTEM_TOGGLE_OFF_PRESSED 46
