#include <ESPMegaProOS.hpp>
#include <ClimateCard.hpp>
#include <ETH.h>
#include <RemoteVariable.hpp>
#include "lcd_elements.hpp"
#include "ir_codes.hpp"
#include "cud_display.hpp"

/***********************************************
 *               Pin Definitions               *
 ***********************************************/
// There are 4 rows of lights
#define LIGHT_ROW_1_PIN 0
#define LIGHT_ROW_2_PIN 1
#define LIGHT_ROW_3_PIN 2
#define LIGHT_ROW_4_PIN 3
// There are 3 rows of fans
#define FAN_ROW_1_PIN 4
#define FAN_ROW_2_PIN 5
#define FAN_ROW_3_PIN 6
// There are one power relay for the air purifier
#define AIR_PURIFIER_PIN 7
// There are one power relay for the mosquito zapper
#define MOSQUITO_ZAPPER_PIN 8

/***********************************************
 *               Air Conditioner               *
 ***********************************************/
// @note The infrared codes are defined in ir_codes.hpp and ir_codes.cpp
#define AC_MIN_TEMP 16
#define AC_MAX_TEMP 32
#define AC_MODES 3
#define AC_FAN_SPEEDS 4
#define AC_MODE_NAMES {"off", "cool", "fan_only"}
#define AC_FAN_SPEED_NAMES {"auto", "high", "medium", "low"}
#define AC_IR_TX_PIN 12 // GP Type
#define AC_IR_CHANNEL RMT_CHANNEL_0
#define AC_SENSOR_TYPE AC_SENSOR_TYPE_DHT22
#define AC_SENSOR_PIN 32 // GP Type

/***********************************************
 *            Display Configuration            *
 ***********************************************/
// UART Configuration
#define INTERNAL_DISPLAY_UART Serial
#define INTERNAL_DISPLAY_BAUDRATE 115200
#define DISPLAY_UART Serial1
#define DISPLAY_TX 4
#define DISPLAY_RX 17
#define DISPLAY_COMMUNICATION_BAUDRATE 115200
#define DISPLAY_OTA_BAUDRATE 921600

/***********************************************
 *      Persistent Storage Configuration       *
 ***********************************************/
#define AC_FRAM_ADDR 5000 // 2 bytes
#define AC_LOCK_FRAM_ADDR 5002 // 1 byte
#define AC_DISPLAY_MODE_FRAM_ADDR 5003 // 1 byte

/***********************************************
 *               Remote Variables              *
 ***********************************************/
#define AQI_STATE_TOPIC "/iqair/usaqi"
#define AQI_REQUEST_TOPIC "/iqair/request"

/***********************************************
 *             Function Prototypes             *
 ***********************************************/
void setup();
void loop();
void send_stop_bytes(HardwareSerial &uart);
void handle_input_change(uint8_t pin, bool state);